==> MCFactory-2.5.8.zip: MCFactory/lang/en_US.php <==
<?php

$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['uninstalled'] = 'Module uninstalled.';

$lang['admindescription'] = 'A module to generate modules for custom content types.';
$lang['installpostmessage'] = 'MC Factory was successfully installed. You can access it and generate new modules through the Extensions menu.';
$lang['uninstallpremessage'] = 'Are you sure you want to uninstall MC Factory? This will also remove all settings for generated modules.';
$lang['uninstallpostmessage'] = 'MC Factory was successfully uninstalled. You can reinstall it at any time.';

$lang['help'] = '
	<h3>Description</h3>
	<p>This module can generate new modules to manage custom content types.</p>
	<h3>Support</h3>
	<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
	<h3>Copyright and License</h3>
	<p>Copyright 2008-2009, <a href="http://www.morris-chapman.com/">Morris &amp; Chapman Belgium</a>.</p>
	<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using this module.</p>
';

$lang['changelog'] = '
	<dl>
		<dt>Version 0.0.1 - 29 September 2008.</dt>
		<dd>Initial Release.</dd>
		<dt>Version 1.0 - 21 October 2009.</dt>
		<dd>First stable release.</dd>
		<dt>Version 1.0.1 - 22 October 2009.</dt>
		<dd>
			<ul>
				<li>Clean-up of the code.</li>
				<li>Models of already installed modules are auto-updated when adding new columns.</li>
			</ul>
		</dd>
	</dl>
';

?>

==> MCFactory-2.9.0.zip: MCFactory/lang/en_US.php <==
<?php

$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['uninstalled'] = 'Module uninstalled.';

$lang['admindescription'] = 'A module to generate modules for custom content types.';
$lang['installpostmessage'] = 'M&amp;C Factory was successfully installed. You can access it and generate new modules through the Extensions menu.';
$lang['uninstallpremessage'] = 'Are you sure you want to uninstall MC Factory? This will also remove all settings for generated modules.';
$lang['uninstallpostmessage'] = 'M&amp;C Factory was successfully uninstalled. You can reinstall it at any time.';
$lang['error_occured_publishing'] = 'An error occured during the publication of the module';

$lang['delete'] = 'Delete';
$lang['move_up'] = 'Move up';
$lang['move_down'] = 'Move down';

$lang['help'] = '
	<h3>Description</h3>
	<p>This module can generate new modules to manage custom content types.</p>
	<h3>Support</h3>
	<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
	<h3>Copyright and License</h3>
	<p>Copyright &copy; 2008-2010, Jean-Christophe Cuvelier <a href="mailto:jcc@morris-chapman.com">&lt;jcc@morris-chapman.com&gt;</a> - <a href="http://www.morris-chapman.com/">Morris &amp; Chapman Belgium</a>.</p>
	<p>Contributors: Gerry Vandermaesen</p>
	<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using this module.</p>
';

$lang['changelog'] = '
	<dl>
		<dt>Version 0.0.1 - 29 September 2008.</dt>
		<dd>Initial Release.</dd>
		<dt>Version 1.0 - 21 October 2009.</dt>
		<dd>First stable release.</dd>
		<dt>Version 1.0.1 - 22 October 2009.</dt>
		<dd>
			<ul>
				<li>Clean-up of the code.</li>
				<li>Models of already installed modules are auto-updated when adding new columns.</li>
			</ul>
		</dd>
	</dl>
';
